#
# spec file for package usbprog
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# RHEL and CentOS have no wxGTK, so we cannot build the GUI here
%if 0%{?rhel_version} || 0%{?centos_version}
%define         build_gui 0
%define         readme_name README.RedHat
%define         group_name uucp
%endif

%if 0%{?fedora_version}
%define         build_gui 1
%define         readme_name README.Fedora
%define         group_name dialout
%endif

%if 0%{?suse_version}
%define         build_gui 1
%define         readme_name README.SUSE

%if 0%{?suse_version} >= 1120
%define         group_name dialout
%else
%define         group_name uucp
%endif

%endif

Name:           usbprog
Version:        0.2.0
Release:        2.3
Url:            http://www.embedded-projects.net/index.php?page_id=165
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2
Source1:        README.distribution
Patch0:         usbprog-wxwidgets-2.4.diff
Summary:        Programmer for the USBprog hardware
License:        GPL-2.0+ and CC-BY-SA-3.0
Group:          Development/Tools/Other

BuildRequires:  gcc-c++
BuildRequires:  libusb-devel
BuildRequires:  libxml2-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(udev)
%if %{build_gui}
%if 0%{?suse_version} > 1130
BuildRequires:  python-wxWidgets
BuildRequires:  wxWidgets-devel
%else
BuildRequires:  python-wxGTK
BuildRequires:  wxGTK-devel
%endif
%endif

%if 0%{?suse_version} >= 1030
BuildRequires:  libcurl-devel
%else
BuildRequires:  curl-devel
%endif

%if 0%{?suse_version} >= 1010
BuildRequires:  pkg-config
%else
BuildRequires:  pkgconfig
%endif

%if 0%{?suse_version} > 1130
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif

%define _udevdir %(pkg-config --variable=udevdir udev)
%define _udevrulesdir %{_udevdir}/rules.d

%description
USBprog is a programmer for the USBprog hardware.

Author
------
        Bernhard Walle <bernhard@bwalle.de>

%if %{build_gui}

%package gui
Requires:       %{name} = %{version}
Summary:        GUI program of USBprog
Group:          Development/Tools/Other

%description gui
A wxGTK version of the USBprog programmer.

Author
------
        Bernhard Walle <bernhard@bwalle.de>

%endif

%package -n libusbprog0
Requires:       %{name} = %{version}
Summary:        USBprog Library
Group:          Development/Tools/Other

%description -n libusbprog0
Library for USBprog.

Author
------
        Bernhard Walle <bernhard@bwalle.de>


%package devel
Requires:       %{name} = %{version}
Summary:        Development files for libusbprog
Group:          Development/Tools/Other

%description devel
Header files for libusbprog.

Author
------
        Bernhard Walle <bernhard@bwalle.de>


%prep
%setup -q
%patch0 -p1

%build
%configure
make %{?_smp_mflags}

%install
%makeinstall
%if %{build_gui} == 0
rm -f $RPM_BUILD_ROOT/%{_datadir}/applications/usbprog.desktop
rm -f $RPM_BUILD_ROOT/%{_datadir}/pixmaps/usbprog_icon.xpm
%endif
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.*a
mkdir -p %{buildroot}%{_udevrulesdir}
sed -e 's/@@USBPROG_GROUP@@/'%{group_name}'/g' usbprog.rules.in \
        > %{buildroot}%{_udevrulesdir}/98-usbprog.rules
sed -e 's/@@USBPROG_GROUP@@/'%{group_name}'/g' %{S:1} > %{readme_name}

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -n libusbprog0 -p /sbin/ldconfig

%postun -n libusbprog0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING ChangeLog NEWS %{readme_name}
%doc %{_datadir}/doc/usbprog/USBprog.pdf
%dir %{_datadir}/doc/usbprog
%{_bindir}/usbprog
%{_mandir}/man1/usbprog.1*
%{_udevrulesdir}/98-usbprog.rules

%files -n libusbprog0
%defattr(-,root,root)
%{_libdir}/*so.*

%if %{build_gui}

%files gui
%defattr(-,root,root)
%{_bindir}/usbprog-gui
%{_datadir}/applications/usbprog.desktop
%{_datadir}/pixmaps/usbprog_icon.xpm
%{_mandir}/man1/usbprog-gui.1*

%endif

%files devel
%defattr(-,root,root)
%{_includedir}/usbprog
%{_libdir}/*so

%changelog
* Thu May  9 2013 crrodriguez@opensuse.org
- Place udev rules in the correct directory, /etc/udev/*
  will be soon blacklisted for use in packages.
* Tue Dec 13 2011 cfarrell@suse.com
- license update: GPL-2.0+ and CC-BY-SA-3.0
  Aggregation of GPL-2.0+ code and CC-BY-SA-3.0 doc, using SPDX format
  (http://www.spdx.org/licenses)
* Thu Dec  8 2011 coolo@suse.com
- the license seems to be GPL-2.0+
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Wed Jan  6 2010 bernhard@bwalle.de
- Add patch 'usbprog-wxwidgets-2.4.diff' that allows the package
  to be built on SLE 10.
* Tue Jan  5 2010 bernhard@bwalle.de
- Update to 0.2.0
  o Install PDF documentation and add a new menu entry in "Help"
    that opens a PDF viewer and shows that PDF documentation.
  o Rename "JP" to "JP4" in the pin information dialog to make it
    more clear that the "JP4" jumper is the firmware-specific one.
  o MacOS:
  - Fix the problem that the menu bar is not displayed on MacOS.
  - Build system fixes for MacOS.
  o Windows:
  - Don't install the filter driver on Win32. This makes USBprog
    compatible with Windows Vista and Windows 7.
  - Register the uninstaller on Windows in the Control Panel.
  - Install the driver files in c:\Program Files\USBprog\driver.
  - Ensure that the complete program directory gets uninstalled.
* Tue Jan  5 2010 bernhard@bwalle.de
- SUSE only: Change 'uucp' to 'dialout' for openSUSE >= 11.2 since
  the serial devices belong to 'dialout' since that release.
* Sun Jan  3 2010 bernhard@bwalle.de
- Make spec file more generic (cleanup).
- Fedora/RHEL/CentOS only: Add udev rules file also for that
  distribution. Use 'uucp' group on RHEL 5/CentOS 5 and 'dialout'
  on recent Fedora versions. See also README.$distribution.
* Sun Jan  3 2010 bernhard@bwalle.de
- Don't install the static library.
- SUSE only: Add udev rules file (98-usbprog.rules) to add USBprog
  devices to the 'uucp' group. See also README.SUSE.
* Sat Jan  2 2010 bernhard@bwalle.de
- Remove workaround (BuildRequires) in spec file for Fedora since
  that seems to be fixed in Fedora build targets of the OBS.
* Sun Nov 29 2009 bernhard@bwalle.de
- update to 0.1.10 (no functional changes on Linux)
* Sun Apr  5 2009 bernhard@bwalle.de
- update to 0.1.9
  o Print error when downloading fails with a non 400 status code.
  o Fix GUI on MacOS X (contributed by Nabil Sayegh)
* Tue Jan 27 2009 bwalle@suse.de
- update to 0.1.8
  o fix tab completion for multiple matches (like 'device' and
    'devices')
  o Fix problem with recent wxGtk versions that the whole GUI was
    hanging when updating the progress bar.
* Thu Jul  3 2008 bwalle@suse.de
- update to 0.1.7
  o fix problem that firmware with more than 16k can't be flashed
- remove usbprog-fix-nonvoid: merged upstream
* Mon May  5 2008 bwalle@suse.de
- fix usbprog no-return-in-nonvoid-function commands.cc: 987
* Wed Mar 26 2008 bwalle@suse.de
- use %%postun -p to avoid extra shell
* Tue Mar 25 2008 bwalle@suse.de
- update to 0.1.6
  o CLI: fix mechanism to avoid downloading the index file again
    and again if the CLI is invoked repeatedly in small intervals
  o remove GPL-incompatible md5_loc.h from source distribution
- remove usbprog-build-fixes: fix for usbprog.desktop upstream
* Thu Mar 20 2008 bwalle@suse.de
- don't package INSTALL
- run ldconfig
* Tue Mar 18 2008 bwalle@suse.de
- fix build on SUSE Linux 10.0 (RPM parser problem)
* Tue Mar 18 2008 bwalle@suse.de
- don't build GUI package on CentOS/RHEL
* Sun Mar 16 2008 bwalle@suse.de
- update to 0.1.5 final
  o GUI: implemented -h / -v / -D command line options for GUI
  o CLI: implement command completion
* Sun Mar  9 2008 bwalle@suse.de
- don't build the GUI for CentOS and RHEL due to lacking wxGtk
* Sat Mar  1 2008 bwalle@suse.de
- update to 0.1.5
  o install icon and destop file
* Sat Feb  9 2008 bwalle@suse.de
- update to 0.1.4
  o Windows: honor IE proxy settings
  o CLI: make (Internet) download progress working
  o CLI: always re-discover devices with the "devices" command
  o CLI: new "start" command to only start the firmware without
    uploading anything and added "-nostart" option to "upload"
    command
  o Unix: build system fixes
* Sun Jan 13 2008 bwalle@suse.de
- update to 0.1.3
  o GUI: fix local upload
  o GUI: make offline mode working, show only firmwares that are
    available offline
* Sun Jan  6 2008 bwalle@suse.de
- update to 0.1.2
  o improved error handling
  o autoconf fixes (building without GUI is now possible)
  o CLI: new string tokenizer to be able to deal with spaces
    (use "string with spaces" or string\ with\ spaces like in bash)
  o GUI: new firmware and pin information
* Fri Jan  4 2008 bwalle@suse.de
- fix build for Fedora 8
* Tue Jan  1 2008 bwalle@suse.de
- update to 0.1.1
  o compilation and build fixes
  o CLI: improve debugging messages
  o GUI: new "logfile" option for debugging
  o Windows: fix problem that download is corrupted
  o add support for checksum testing after download to ensure that
    the download was correct
* Thu Dec 27 2007 bwalle@suse.de
- fix build for gcc 4.3
* Thu Dec 27 2007 bwalle@suse.de
- intial SUSE package
